@@ -5,7 +5,16 @@ import os
 import pkgutil
 import re
 from collections import defaultdict
-from typing import TYPE_CHECKING, Any, Callable, Iterable, List, Tuple, TypeVar
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    DefaultDict,
+    Iterable,
+    List,
+    Tuple,
+    TypeVar,
+)
 
 from tokenize_rt import Offset, Token
 
@@ -13,28 +22,45 @@ from django_upgrade import fixers
 
 
 class Settings:
+    __slots__ = ("target_version",)
+
     def __init__(self, target_version: tuple[int, int]) -> None:
         self.target_version = target_version
 
 
-settings_re = re.compile(r"\bsettings\b")
-
-test_re = re.compile(r"(\b|_)tests?(\b|_)")
-
+admin_re = re.compile(r"(\b|_)admin(\b|_)")
 dunder_init_re = re.compile(r"(^|[\\/])__init__\.py$")
+settings_re = re.compile(r"(\b|_)settings(\b|_)")
+test_re = re.compile(r"(\b|_)tests?(\b|_)")
 
 
 class State:
+    __slots__ = ("settings", "filename", "from_imports", "__weakref__")
+
     def __init__(
         self,
         settings: Settings,
         filename: str,
-        from_imports: dict[str, set[str]],
+        from_imports: DefaultDict[str, set[str]],
     ) -> None:
         self.settings = settings
         self.filename = filename
         self.from_imports = from_imports
 
+    def looks_like_admin_file(self) -> bool:
+        return admin_re.search(self.filename) is not None
+
+    def looks_like_command_file(self) -> bool:
+        parts = self.filename.split(os.path.sep)
+        try:
+            i = parts.index("commands")
+        except ValueError:
+            return False
+        return i > 0 and i < (len(parts) - 1) and parts[i - 1] == "management"
+
+    def looks_like_dunder_init_file(self) -> bool:
+        return dunder_init_re.search(self.filename) is not None
+
     def looks_like_migrations_file(self) -> bool:
         return "migrations" in self.filename.split(os.path.sep)
 
@@ -44,13 +70,10 @@ class State:
     def looks_like_test_file(self) -> bool:
         return test_re.search(self.filename) is not None
 
-    def looks_like_dunder_init_file(self) -> bool:
-        return dunder_init_re.search(self.filename) is not None
-
 
 AST_T = TypeVar("AST_T", bound=ast.AST)
 TokenFunc = Callable[[List[Token], int], None]
-ASTFunc = Callable[[State, AST_T, ast.AST], Iterable[Tuple[Offset, TokenFunc]]]
+ASTFunc = Callable[[State, AST_T, List[ast.AST]], Iterable[Tuple[Offset, TokenFunc]]]
 
 if TYPE_CHECKING:  # pragma: no cover
     from typing import Protocol
@@ -79,12 +102,17 @@ def visit(
     )
 
     nodes: list[tuple[State, ast.AST, ast.AST]] = [(initial_state, tree, tree)]
+    parents: list[ast.AST] = [tree]
     ret = defaultdict(list)
     while nodes:
         state, node, parent = nodes.pop()
+        if len(parents) > 1 and parent == parents[-2]:
+            parents.pop()
+        elif parent != parents[-1]:
+            parents.append(parent)
 
         for ast_func in ast_funcs[type(node)]:
-            for offset, token_func in ast_func(state, node, parent):
+            for offset, token_func in ast_func(state, node, parents):
                 ret[offset].append(token_func)
 
         if (
@@ -115,6 +143,8 @@ def visit(
 
 
 class Fixer:
+    __slots__ = ("name", "min_version", "ast_funcs")
+
     def __init__(self, name: str, min_version: tuple[int, int]) -> None:
         self.name = name
         self.min_version = min_version
