@@ -21,17 +21,14 @@ fixer = Fixer(
 
 MODULE = "django.core.validators"
 NAME = "EmailValidator"
-KWARGS = {
-    "whitelist": "allowlist",
-    "domain_whitelist": "domain_allowlist",
-}
+KWARGS = {"whitelist": "allowlist"}
 
 
 @fixer.register(ast.Call)
 def visit_Call(
     state: State,
     node: ast.Call,
-    parent: ast.AST,
+    parents: list[ast.AST],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         (
