@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import ast
+import re
 from collections import defaultdict
 
 from tokenize_rt import NON_CODING_TOKENS, UNIMPORTANT_WS, Token, tokens_to_src
@@ -60,7 +61,22 @@ def reverse_consume(
     return i
 
 
-def find_final_token(tokens: list[Token], i: int, *, node: ast.AST) -> int:
+def find_first_token(tokens: list[Token], i: int, *, node: ast.AST) -> int:
+    """
+    Find the first token corresponding to the given ast node.
+    """
+    j = i
+    while tokens[j].line is None or tokens[j].line < node.lineno:
+        j += 1
+    while (
+        tokens[j].utf8_byte_offset is None
+        or tokens[j].utf8_byte_offset < node.col_offset
+    ):
+        j += 1
+    return j
+
+
+def find_last_token(tokens: list[Token], i: int, *, node: ast.AST) -> int:
     """
     Find the last token corresponding to the given ast node.
     """
@@ -72,7 +88,7 @@ def find_final_token(tokens: list[Token], i: int, *, node: ast.AST) -> int:
         or tokens[j].utf8_byte_offset < node.end_col_offset
     ):
         j += 1
-    return j
+    return j - 1
 
 
 def extract_indent(tokens: list[Token], i: int) -> tuple[int, str]:
@@ -81,7 +97,7 @@ def extract_indent(tokens: list[Token], i: int) -> tuple[int, str]:
     indentation string. Otherwise return the current position and "".
     """
     j = i
-    if j > 0 and tokens[j - 1].name == INDENT:
+    if j > 0 and tokens[j - 1].name in (INDENT, UNIMPORTANT_WS):
         j -= 1
         indent = tokens[j].src
     else:
@@ -165,6 +181,8 @@ class Block:  # pragma: no cover
     MIT Licensed
     """
 
+    __slots__ = ("start", "colon", "block", "end", "line")
+
     def __init__(
         self, start: int, colon: int, block: int, end: int, line: bool
     ) -> None:
@@ -318,11 +336,15 @@ def erase_node(tokens: list[Token], i: int, *, node: ast.AST) -> None:
     """
     Erase all tokens corresponding to the given ast node.
     """
-    j = find_final_token(tokens, i, node=node)
-    if tokens[j].name == LOGICAL_NEWLINE:  # pragma: no branch
+    j = find_last_token(tokens, i, node=node)
+    if tokens[j + 1].name == UNIMPORTANT_WS:
+        j += 1
+    if tokens[j + 1].name == COMMENT:
+        j += 1
+    if tokens[j + 1].name == LOGICAL_NEWLINE:  # pragma: no branch
         j += 1
     i, _ = extract_indent(tokens, i)
-    del tokens[i:j]
+    del tokens[i : j + 1]
 
 
 def find_and_replace_name(tokens: list[Token], i: int, *, name: str, new: str) -> None:
@@ -347,7 +369,6 @@ def replace_argument_names(
 
     for n, keyword in reversed(list(enumerate(node.keywords))):
         if keyword.arg in arg_map:
-            x, y = kwarg_func_args[n]
             for k in range(*kwarg_func_args[n]):
                 if tokens[k].src == keyword.arg:
                     tokens[k] = tokens[k]._replace(src=arg_map[keyword.arg])
@@ -356,6 +377,27 @@ def replace_argument_names(
                 raise AssertionError(f"{keyword.arg} argument not found")
 
 
+str_repr_single_to_double = str.maketrans(
+    {
+        "'": '"',
+        '"': '\\"',
+    }
+)
+
+
+def str_repr_matching(text: str, *, match_quotes: str) -> str:
+    """
+    Give the repr of a string, switching it to double quotes if the string
+    literal represent in match_quotes uses double quotes.
+    """
+    result = repr(text)
+    first_quote = re.search(r'[\'"]', match_quotes)
+    assert first_quote is not None
+    if first_quote[0] == '"' and result[0] != '"':
+        result = result.translate(str_repr_single_to_double)
+    return result
+
+
 def update_import_names(
     tokens: list[Token],
     i: int,
@@ -381,7 +423,7 @@ def update_import_names(
             # Skip over
             remove_all = False
             j = find(tokens, j, name=NAME, src=alias.name)
-            if alias.asname is not None:  # pragma: no branch
+            if alias.asname is not None:
                 j = find(tokens, j, name=NAME, src="as")
                 j = find(tokens, j, name=NAME, src=alias.asname)
             continue
@@ -392,12 +434,12 @@ def update_import_names(
             start_idx = find(tokens, j, name=NAME, src=alias.name)
 
             end_idx = start_idx
-            if alias.asname is not None:  # pragma: no cover
+            if alias.asname is not None:
                 end_idx = find(tokens, end_idx, name=NAME, src="as")
                 end_idx = find(tokens, end_idx, name=NAME, src=alias.asname)
 
             if len(node.names) > 1:
-                if alias_idx < len(node.names) - 1:
+                if alias_idx == 0:
                     end_idx = find(tokens, end_idx, name=OP, src=",")
                 else:
                     start_idx = reverse_find(tokens, start_idx, name=OP, src=",")
